<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=hr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Hrvatski [hr]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'Alexander Gehrecke (a_gehrecke(at)ambinet.de)',

	// A
	'access_interface_graphique' => 'Natrag u potpuni grafički interface',
	'access_mode_texte' => 'Pojednostavljeni text interface',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Izmijeniti ovaj članak',
	'admin_modifier_auteur' => 'Izmjeniti podatke ovoga autora',
	'admin_modifier_breve' => 'Izmjeniti ovu vijest',
	'admin_modifier_mot' => 'Izmjeniti ovu ključnu riječ',
	'admin_modifier_rubrique' => 'Izmjeniti ovu rubriku',
	'admin_recalculer' => 'Osvježiti ovu stranicu',
	'afficher_calendrier' => 'Prikazati kalendar',
	'afficher_trad' => 'pokaži prijevode',
	'alerte_maj_impossible' => '<b>Pozor!</b> Neuspjeo pokušaj promjene verzije SQL baze podataka u verziju @version@, moguće uslijed nedostatnih prava. Molimo stupite u kontakt s Vašim ISP.',
	'alerte_modif_info_concourante' => 'UPOZORENJE : Ova informacija je drugdje već promjenjena. Trenutna vrijednost je :',
	'analyse_xml' => 'XML analiza',
	'annuler' => 'Poništiti',
	'antispam_champ_vide' => 'Molim ostavite ovo polje prazno:',
	'articles_recents' => 'Najnoviji članci',
	'avis_archive_incorrect' => 'datoteka (arhiva) nije ispravna SPIP datoteka',
	'avis_archive_invalide' => 'datoteka (arhiva) nije ispravna',
	'avis_attention' => 'POZOR!',
	'avis_champ_incorrect_type_objet' => 'Nevaljan naziv polja @name@ za objekt vrste @type@',
	'avis_colonne_inexistante' => 'Kolona @col@ ne postoji',
	'avis_erreur' => 'Greška: vidi dolje',
	'avis_erreur_connexion' => 'Greška pri priključivanju',
	'avis_erreur_cookie' => 'problem sa cookiem',
	'avis_erreur_fonction_contexte' => 'Programska greška. Ova funkcija ne smije biti pozvana u ovom kontekstu.',
	'avis_erreur_mysql' => 'SQL greška',
	'avis_erreur_sauvegarde' => 'Greška u sigurnosnoj kopiji (backup) (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problem pri ulasku u privatnu dio',

	// B
	'barre_a_accent_grave' => 'Umetnite veliko A sa silaznim akcentom',
	'barre_aide' => 'Upotrijebite tipografske kratice da biste oplemenili izgled',
	'barre_e_accent_aigu' => 'Umetnite veliko E s uzlaznim akcentom',
	'barre_eo' => 'Umetnite oe-ligaturu',
	'barre_eo_maj' => 'Umetnite veliku OE-ligaturu',
	'barre_euro' => 'Umetnite € simbol',
	'barre_gras' => 'koristite {{debelo otisnuta slova}}',
	'barre_guillemets' => 'umetnite u "dvostruke navodnike"',
	'barre_guillemets_simples' => 'umetnite u ‘jednostruke navodnike’',
	'barre_intertitre' => 'promijenite u {{{podnaslov}}}',
	'barre_italic' => 'koristite {kurziv}',
	'barre_lien' => 'promjenite u [hiperlink->http://...]',
	'barre_lien_input' => 'Unesite cilj hiperlinka (možete unijeti internet URL u obliku http://www.mysite.com ili jednostavno broj članka na ovim web stranicama).',
	'barre_note' => 'Promjenite u [[napomenu]]',
	'barre_paragraphe' => 'Napraviti paragraf',
	'barre_quote' => '<quote>citirajte poruku</quote>',
	'bouton_changer' => 'Izmjeniti',
	'bouton_chercher' => 'Tražiti',
	'bouton_choisir' => 'Birati',
	'bouton_deplacer' => 'Premjestiti',
	'bouton_download' => 'Preuzimanje',
	'bouton_enregistrer' => 'Sačuvati',
	'bouton_radio_desactiver_messagerie_interne' => 'Deaktivirati interne poruke',
	'bouton_radio_envoi_annonces' => 'Poslati autorske objave',
	'bouton_radio_non_envoi_annonces' => 'Ne slati nikakve objave',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Ne slati listu posljednjih vijesti',
	'bouton_recharger_page' => 'osvježiti ovu stranicu',
	'bouton_telecharger' => 'Otprema',
	'bouton_upload' => 'uploadati',
	'bouton_valider' => 'Potvrditi',

	// C
	'cal_apresmidi' => 'poslijepodne (p.m.)',
	'cal_jour_entier' => 'cijeli dan',
	'cal_matin' => 'prijepodne (a.m.)',
	'cal_par_jour' => 'dnevni kalendar',
	'cal_par_mois' => 'mjesečni kalendar',
	'cal_par_semaine' => 'tjedni kalendar',
	'choix_couleur_interface' => 'boja',
	'choix_interface' => 'izbor sučelja',
	'colonne' => 'Stupac',
	'confirm_changer_statut' => 'Potrebna potvrda: Odabrali ste promjenu statusa ovoga članka. Želite li nastaviti?',
	'correcte' => 'ispravno',

	// D
	'date_aujourdhui' => 'danas',
	'date_avant_jc' => 'p.n.e.',
	'date_dans' => 'u @delai@',
	'date_de_mois_1' => '@j@ siječnja',
	'date_de_mois_10' => '@j@ listopada',
	'date_de_mois_11' => '@j@ studenog',
	'date_de_mois_12' => '@j@ prosinca',
	'date_de_mois_2' => '@j@ veljače',
	'date_de_mois_3' => '@j@ ožujka',
	'date_de_mois_4' => '@j@ travnja',
	'date_de_mois_5' => '@j@ svibnja',
	'date_de_mois_6' => '@j@ lipnja',
	'date_de_mois_7' => '@j@ srpnja',
	'date_de_mois_8' => '@j@ kolovoza',
	'date_de_mois_9' => '@j@ rujna',
	'date_demain' => 'sutra',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ u @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ od @heure_debut@ do @heure_fin@', # MODIF
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ od @heure_debut@@dtabbr@ do @dtend@@heure_fin@@dtabbr@', # MODIF
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@nomjour@, @date@',
	'date_fmt_periode' => 'Od @date_debut@ do @date_fin@',
	'date_fmt_periode_abbr' => 'Od @dtart@@date_debut@@dtabbr@ do @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Od',
	'date_fmt_periode_to' => 'do',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'sati',
	'date_hier' => 'jučer',
	'date_il_y_a' => 'prije @delai@',
	'date_jnum1' => '1.',
	'date_jnum10' => '10.',
	'date_jnum11' => '11.',
	'date_jnum12' => '12.',
	'date_jnum13' => '13.',
	'date_jnum14' => '14.',
	'date_jnum15' => '15.',
	'date_jnum16' => '16.',
	'date_jnum17' => '17.',
	'date_jnum18' => '18.',
	'date_jnum19' => '19.',
	'date_jnum2' => '2.',
	'date_jnum20' => '20.',
	'date_jnum21' => '21.',
	'date_jnum22' => '22.',
	'date_jnum23' => '23.',
	'date_jnum24' => '24.',
	'date_jnum25' => '25.',
	'date_jnum26' => '26.',
	'date_jnum27' => '27.',
	'date_jnum28' => '28.',
	'date_jnum29' => '29.',
	'date_jnum3' => '3.',
	'date_jnum30' => '30.',
	'date_jnum31' => '31.',
	'date_jnum4' => '4.',
	'date_jnum5' => '5.',
	'date_jnum6' => '6.',
	'date_jnum7' => '7.',
	'date_jnum8' => '8.',
	'date_jnum9' => '9.',
	'date_jour_1' => 'Nedjelja',
	'date_jour_1_abbr' => 'ne.',
	'date_jour_1_initiale' => 'n.',
	'date_jour_2' => 'Ponedjeljak',
	'date_jour_2_abbr' => 'pon.',
	'date_jour_2_initiale' => 'p.',
	'date_jour_3' => 'Utorak',
	'date_jour_3_abbr' => 'uto.',
	'date_jour_3_initiale' => 'u.',
	'date_jour_4' => 'Srijeda',
	'date_jour_4_abbr' => 'sri.',
	'date_jour_4_initiale' => 's.',
	'date_jour_5' => 'Četvrtak',
	'date_jour_5_abbr' => 'čet.',
	'date_jour_5_initiale' => 'č.',
	'date_jour_6' => 'Petak',
	'date_jour_6_abbr' => 'pe.',
	'date_jour_6_initiale' => 'p.',
	'date_jour_7' => 'Subota',
	'date_jour_7_abbr' => 'sub.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'dana',
	'date_minutes' => 'minuta',
	'date_mois' => 'mjeseci',
	'date_mois_1' => 'Sječanj',
	'date_mois_10' => 'Listopad',
	'date_mois_10_abbr' => 'list.',
	'date_mois_11' => 'Studeni',
	'date_mois_11_abbr' => 'stud.',
	'date_mois_12' => 'Prosinac',
	'date_mois_12_abbr' => 'pros.',
	'date_mois_1_abbr' => 'sije.',
	'date_mois_2' => 'Veljača',
	'date_mois_2_abbr' => 'velj.',
	'date_mois_3' => 'Ožujak',
	'date_mois_3_abbr' => 'ožuj.',
	'date_mois_4' => 'Travanj',
	'date_mois_4_abbr' => 'trav.',
	'date_mois_5' => 'Svibanj',
	'date_mois_5_abbr' => 'svib.',
	'date_mois_6' => 'Lipanj',
	'date_mois_6_abbr' => 'lip.',
	'date_mois_7' => 'Srpanj',
	'date_mois_7_abbr' => 'srp.',
	'date_mois_8' => 'Kolovoz',
	'date_mois_8_abbr' => 'kolov.',
	'date_mois_9' => 'Rujan',
	'date_mois_9_abbr' => 'ruj.',
	'date_saison_1' => 'zima',
	'date_saison_2' => 'proljeće',
	'date_saison_3' => 'ljeto',
	'date_saison_4' => 'jesen',
	'date_secondes' => 'sekunde',
	'date_semaines' => 'tjedana',
	'date_un_mois' => 'mjesec',
	'date_une_heure' => 'sat',
	'date_une_minute' => 'minuta',
	'date_une_seconde' => 'sekundi',
	'date_une_semaine' => 'tjedana',
	'dirs_commencer' => ' da biste doista započeli instalaciju',
	'dirs_preliminaire' => 'Priprema: <b>podešavanje dozvole pristupa</b>',
	'dirs_probleme_droits' => 'Problem sa dozvolama pristupa',
	'dirs_repertoires_absents' => '<p><b>Slijedeći direktoriji nisu nađeni: </b></p><ul>@bad_dirs@.</ul>
  <p>Mogući uzrok može biti greška u pisanju malih / velikih slova.
  Uvjerite se da su mala i velika slova ovih direktorija istovjetna sa gore prikazanim imenima. Ako to nije slučaj, promijenite nazive direktorija koristeći Vaš FTP program.</p>
  <p>Kada to napravite, onda možete',
	'dirs_repertoires_suivants' => '<p><b>U slijedeće direktorije nije moguće pisati: </b></p><ul>@bad_dirs@</ul>
 <p>Da biste to promijenili, upotrijebite Vaš FTP program i promijenite dozvole pristupa za svaki od navedenih direktorija. Ovo je detaljno objašnjeno u uputi za instalaciju.</p>
  <p>Kada to napravite, onda možete ',
	'double_occurrence' => 'Dvije instance',

	// E
	'en_cours' => 'obrada',
	'envoi_via_le_site' => 'Poslati preko web stranica',
	'erreur' => 'Greška',
	'erreur_balise_non_fermee' => 'poslednja oznaka nije zatvorena:',
	'erreur_technique_ajaxform' => 'Ops. Neočekivana greška onemogućila je slanje formulara. Možete ponovno pokušati.',
	'erreur_technique_enregistrement_champs' => 'Tehnička pogreška onemogućila je uredno pohranjivanje polja @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Tehnička pogreška onemogućila je uredno pohranjivanje.',
	'erreur_texte' => 'greška/greške',
	'etape' => 'Stupanj',

	// F
	'fichier_introuvable' => 'Datoteka nije pronađena: @fichier@',
	'form_auteur_confirmation' => 'Potvrdite mail adresu',
	'form_auteur_email_modifie' => 'Vaša mail adresa je promjenjena.',
	'form_auteur_envoi_mail_confirmation' => 'Potvrda je upravo poslana putem elektroničke pošte na @email@. Otvorite navedenu web adresu iz poruke kako biste potvrdili potvrdili vašu mail adresu.',
	'form_auteur_mail_confirmation' => 'Dobar dan,

Zatražili ste izmjenu vaše mail adrese.
Kako biste potvrdili svoju novu adresu, potrebno je samo pristupiti niže navedenoj adresi
(u protivnom će vaš upit biti zanemaren) :

    @url@
',
	'form_deja_inscrit' => 'Već ste se registrirali.',
	'form_email_non_valide' => 'Vaša mail adresa je neispravna.',
	'form_forum_access_refuse' => 'Više nemate pristupa ovime web stranicama.',
	'form_forum_bonjour' => 'Dobar dan @nom@,',
	'form_forum_confirmer_email' => 'Kako biste potvrdili vašu mail adresu, pođite na slijedeću adresu : @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Ova mail adresa je već registrirana, stoga možete koristiti Vašu uobičajenu lozinku.',
	'form_forum_identifiant_mail' => 'Vaši novi podaci su vam upravo poslani na Vašu mail adresu.',
	'form_forum_identifiants' => 'Osobni podaci',
	'form_forum_indiquer_nom_email' => 'Unesite ovdje Vaše ime i mail adresu. Ubrzo ćete primiti mail sa Vašim osobnim podacima.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(ovo je automatska poruka)',
	'form_forum_pass' => 'lozinka:',
	'form_forum_probleme_mail' => 'Problem sa mailom: lozinka Vam nije mogla biti poslana.',
	'form_forum_voici1' => 'Ovdje su Vaši osobni podaci za pristup web stranicama
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Ovdje su Vaši osobni podaci za pisanje članaka na web stranicama
"@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Unesite Vašu mail adresu.',
	'form_indiquer_nom' => 'Unesite Vaše ime.',
	'form_indiquer_nom_site' => 'Unesite ime Vaših web stranica.',
	'form_pet_deja_enregistre' => 'Ove web stranice su već registrirane',
	'form_pet_signature_pasprise' => 'Vaš potpis je ignoriran.',
	'form_prop_confirmer_envoi' => 'Potvrditi odašiljanje',
	'form_prop_description' => 'opis / komentar',
	'form_prop_enregistre' => 'Vaš prijedlog je upamćen, i bit će objavljen nakon što ga provjeri administrator ovih web stranica.',
	'form_prop_envoyer' => 'poslati poruku',
	'form_prop_indiquer_email' => 'Unesite ispravnu mail adresu',
	'form_prop_indiquer_nom_site' => 'Unesite ime web stranica.',
	'form_prop_indiquer_sujet' => 'Unesite temu',
	'form_prop_message_envoye' => 'Poruka poslana',
	'form_prop_non_enregistre' => 'Vaš prijedlog nije upamćen.',
	'form_prop_sujet' => 'Tema',
	'form_prop_url_site' => 'URL web stranica',
	'forum_non_inscrit' => 'Ili još niste registrirani ili je adresa ili lozinka netočna.',
	'forum_par_auteur' => '- @auteur@',
	'forum_titre_erreur' => 'Greška...',

	// I
	'ical_texte_rss_articles' => 'Adresa "backend"-datoteke sa člancima ovih web stranica je:',
	'ical_texte_rss_articles2' => 'Također, možete pristupiti "backend"-datotekama sa člancima pojedinačnih rubrika ovih web stranica:',
	'ical_texte_rss_breves' => 'Osim toga, tu je i datoteka koja sadrži vijesti ovih web stranica. Odabiranjem rubrike ćete dobiti samo vijesti iz te rubrike.',
	'icone_a_suivre' => 'aktivnosti',
	'icone_admin_site' => 'administriranje stranica',
	'icone_agenda' => 'kalendar',
	'icone_aide_ligne' => 'pomoć',
	'icone_articles' => 'članci',
	'icone_auteurs' => 'autori',
	'icone_brouteur' => 'brzi pregled',
	'icone_configuration_site' => 'konfiguracija',
	'icone_configurer_site' => 'konfigurirajte Vaše stranice',
	'icone_creer_nouvel_auteur' => 'dodati novog autora',
	'icone_creer_rubrique' => 'dodati novu rubriku',
	'icone_creer_sous_rubrique' => 'dodati novu podrubriku',
	'icone_deconnecter' => 'odjava',
	'icone_discussions' => 'diskusije',
	'icone_doc_rubrique' => 'pridruženi dokumenti',
	'icone_ecrire_article' => 'napisati novi članak',
	'icone_edition_site' => 'uređivanje stranica',
	'icone_gestion_langues' => 'podešavanje jezika',
	'icone_informations_personnelles' => 'osobni podaci',
	'icone_interface_complet' => 'potpuni interface',
	'icone_interface_simple' => 'pojednostavljeni interface',
	'icone_maintenance_site' => 'održavanje web stranica',
	'icone_messagerie_personnelle' => 'osobne poruke',
	'icone_repartition_debut' => 'prikazati raspodjelu od početka',
	'icone_rubriques' => 'rubrike',
	'icone_sauver_site' => 'sigurnosna kopija web stranica',
	'icone_site_entier' => 'sve web stranice',
	'icone_sites_references' => 'preporučene web stranice',
	'icone_statistiques' => 'statistika web stranica',
	'icone_suivi_activite' => 'praćenje aktivnosti na web stranicama',
	'icone_suivi_actualite' => 'statistika web stranica',
	'icone_suivi_pettions' => 'upravljanje peticijama',
	'icone_suivi_revisions' => 'revizije članaka',
	'icone_supprimer_document' => 'obrisati ovaj dokument',
	'icone_supprimer_image' => 'obrisati ovu sliku',
	'icone_tous_articles' => 'svi Vaši članci',
	'icone_tous_auteur' => 'svi autori',
	'icone_tous_visiteur' => 'Svi posjetitelji',
	'icone_visiter_site' => 'posjetiti web stranice',
	'icone_voir_en_ligne' => 'promatrati on-line',
	'img_indisponible' => 'slika nije na raspolaganju',
	'impossible' => 'nije moguće',
	'info_a_suivre' => 'AKTIVNOSTI»',
	'info_acces_interdit' => 'pristup zabranjen',
	'info_acces_refuse' => 'pristup odrečen',
	'info_action' => 'aktivnost: @action@',
	'info_administrer_rubriques' => 'Možete obrađivati ovu rubriku i njene podrubrike',
	'info_adresse_non_indiquee' => 'Niste odredili adresu za testiranje!',
	'info_aide' => 'POMOĆ:',
	'info_ajouter_mot' => 'dodati ovu ključnu riječ',
	'info_annonce' => 'OBJAVA',
	'info_annonces_generales' => 'opće objave:',
	'info_article_propose' => 'predložen članak',
	'info_article_publie' => 'objavljen članak',
	'info_article_redaction' => 'članak u obradi',
	'info_article_refuse' => 'odbačen članak',
	'info_article_supprime' => 'obrisan članak',
	'info_articles' => 'članci',
	'info_articles_a_valider' => 'članci za provjeru',
	'info_articles_nb' => '@nb@ articles',
	'info_articles_proposes' => 'podnešeni članci',
	'info_articles_un' => '1 članak',
	'info_auteurs_nombre' => 'autor(i):',
	'info_authentification_ftp' => 'provjera identiteta (kroz FTP).',
	'info_breves_2' => 'vijesti',
	'info_breves_nb' => '@nb@ kratke vijesti',
	'info_breves_un' => '1 kratke vijesti',
	'info_connexion_refusee' => 'priključenje odbijeno',
	'info_contact_developpeur' => 'Stupite u vezu s programerom.',
	'info_contenance' => 'Ove stranice sadrže:',
	'info_contribution' => 'forumski prilozi',
	'info_copyright' => '@spip@ je besplatan softver u smislu @lien_gpl@.',
	'info_copyright_doc' => 'Za daljnje informacije, vidi <a href="@spipnet@">http://www.spip.net</a>.',
	'info_copyright_gpl' => 'GPL dozvole',
	'info_cours_edition' => 'Vaši članci u obradi',
	'info_creer_repertoire' => 'Napravite datoteku ili direktorij sa imenom:',
	'info_creer_repertoire_2' => 'u poddirektoriju <b>@repertoire@</b>, i onda',
	'info_creer_vignette' => 'automatska izrada male sličice',
	'info_creerdansrubrique_non_autorise' => 'Nemate dovoljne ovlasti kako biste dodali sadržaj u ovu rubriku',
	'info_deplier' => 'otvoriti',
	'info_descriptif_nombre' => 'opis(i):',
	'info_description' => 'opis:',
	'info_description_2' => 'opis:',
	'info_dimension' => 'veličina:',
	'info_documents_nb' => '@nb@ dokumenti',
	'info_documents_un' => '1 dokument',
	'info_ecire_message_prive' => 'napisati privatnu poruku',
	'info_email_invalide' => 'nepostojeća mail adresa.',
	'info_en_cours_validation' => 'Vaši članci u obradi',
	'info_en_ligne' => 'trenutačno on-line (priključeni):',
	'info_envoyer_message_prive' => 'poslati privatnu poruku ovom autoru',
	'info_erreur_requete' => 'greška u zahtjevu:',
	'info_erreur_squelette2' => 'predložak <b>@fichier@</b> ne stoji na raspolaganju...',
	'info_erreur_systeme' => 'greška u sistemu (broj @errsys@)',
	'info_erreur_systeme2' => 'Disk je pun ili je baza podataka oštećena. <br />
<span style="color:red;">pokušajte <a href=\'@script@\'>popraviti bazu podataka</a>, ili stupite u vezu sa Vašim pružateljem usluga.</span>',
	'info_fini' => 'učinjeno!',
	'info_format_image' => 'format za stvaranje malih sličica: @gd_formats@.',
	'info_format_non_defini' => 'nejasan format',
	'info_grand_ecran' => 'veliki ekran',
	'info_image_aide' => 'POMOĆ',
	'info_image_process_titre' => 'kako izraditi male sličice',
	'info_impossible_lire_page' => '<b>Greška!</b> Stranica <tt><html>@test_proxy@</html></tt> nije mogla biti pročitana preko proxy - računala',
	'info_installation_systeme_publication' => 'instalacija redakcijskog sistema...',
	'info_installer_documents' => 'Možete automatski instalirati sve dokumente koji se nalaze u direktoriju @upload@.',
	'info_installer_ftp' => 'Kao administrator, možete (pomoću FTP) snimiti datoteke u direktorij @upload@, da biste ih poslije ovdje birali.',
	'info_installer_images' => 'Možete instalirati slike u formatima JPEG, GIF ili PNG.',
	'info_installer_images_dossier' => 'Snimite slike u direktorij @upload@ da bi ste ih poslije ovdje mogli odabrati.',
	'info_interface_complete' => 'cjelokupni interface',
	'info_interface_simple' => 'pojednostavljeni interface',
	'info_joindre_document_article' => 'Vašem članku možete pridružiti dokumente tipova',
	'info_joindre_document_rubrique' => 'Ovoj rubrici možete pridružiti dokumente tipova',
	'info_joindre_documents_article' => 'Vašem članku možete pridružiti dokumente tipova:',
	'info_l_article' => 'članak',
	'info_la_breve' => 'vijest',
	'info_la_rubrique' => 'rubrika',
	'info_langue_principale' => 'glavni jezik web stranica',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ točaka',
	'info_les_auteurs_1' => '- @les_auteurs@',
	'info_logo_format_interdit' => 'Dozvoljeni su samo logotipovi formata @formats@.',
	'info_logo_max_poids' => 'Veličina logotipa smije biti najviše @maxi@ (ova datoteka je veličine @actuel@).',
	'info_mail_fournisseur' => 'vašeime@poslužitelj.hr',
	'info_message_2' => 'PORUKA',
	'info_message_supprime' => 'PORUKA OBRISANA',
	'info_messages_nb' => '@nb@ poruka',
	'info_messages_un' => '1 poruka',
	'info_mise_en_ligne' => 'datum objavljivanja:',
	'info_modification_parametres_securite' => 'promjena sigurnosnih parametara',
	'info_mois_courant' => 'tjekom mjeseca:',
	'info_mot_cle_ajoute' => 'slijedeća ključna riječ je pridodana',
	'info_multi_herit' => 'uobičajeni jezik',
	'info_multi_langues_soulignees' => '<u>Podvučeni jezici</u> sadrže potpun prijevod svih djelova sučelja. Odaberete li jedan od tih jezika, mnogi dijelovi javnog dijela weba će biti pisani tim jezikom (datumi, obrasci). Pri odabiru jezika koji nisu podvučeni će ti dijelovi biti pisani na glavnom jeziku weba.',
	'info_multilinguisme' => 'višejezično',
	'info_nom_non_utilisateurs_connectes' => 'Vaše ime se ne pojavljuje u listi spojenih korisnika.',
	'info_nom_utilisateurs_connectes' => 'Vaše ime se pojavljuje u listi spojenih korisnika.',
	'info_nombre_en_ligne' => 'trenutačno spojeni korisnici:',
	'info_non_resultat' => 'nema rezultata za "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Vi ne koristite interne poruke na ovim web stranicama.',
	'info_nouveau_message' => 'IMATE NOVU PORUKU',
	'info_nouveaux_messages' => 'IMATE @total_messages@ NOVIH PORUKA',
	'info_numero_abbreviation' => 'ne',
	'info_obligatoire' => 'Ova informacija je neophodna',
	'info_pense_bete' => 'BILJEŠKA',
	'info_petit_ecran' => 'mali ekran',
	'info_petition_close' => 'Peticija zatvorena',
	'info_pixels' => 'točke',
	'info_plusieurs_mots_trouves' => 'nekoliko ključnih riječi je pronađeno za "@cherche_mot@":',
	'info_portfolio_automatique' => 'automatska mapa:',
	'info_premier_resultat' => '[@debut_limit@ prvih rezultata od ukupno @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ prvih rezultata od ukupno @total@]',
	'info_propose_1' => '[@nom_site_spip@] predloženo od: @titre@',
	'info_propose_2' => 'predložen članak
-----------------',
	'info_propose_3' => 'članak "@titre@" je podnešen za objavljivanje.',
	'info_propose_4' => 'pozvani ste pregledati ga i dati Vaše mišljenje',
	'info_propose_5' => 'u odgovarajućem forumu. Nalazi se na adresi:',
	'info_publie_01' => 'Članak "@titre@" je odobren od @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] OBJAVLJENO: @titre@',
	'info_publie_2' => 'članak objavljen
-----------------',
	'info_rechercher' => 'pretraga',
	'info_rechercher_02' => 'pretraga:',
	'info_remplacer_vignette' => 'Zamjenite standardnu sličicu sa Vašim logotipom:',
	'info_rubriques_nb' => '@nb@ rubrike',
	'info_rubriques_un' => '1 rubrika',
	'info_sans_titre_2' => 'bez naslova',
	'info_selectionner_fichier' => 'možete odabrati datoteku iz direktorija @upload@',
	'info_selectionner_fichier_2' => 'odaberite datoteku:',
	'info_sites_nb' => '@nb@ web stranica',
	'info_sites_un' => '1 web stranica',
	'info_supprimer_vignette' => 'obrisati sličicu',
	'info_symbole_bleu' => 'Simbol <b>plave boje</b> označava <b>bilješku</b>: tojest poruku za Vašu osobnu upotrebu.',
	'info_symbole_jaune' => 'Simbol <b>žute boje</b> označava <b>objavu svim autorima</b>: mogu je mijenjati svi administratori, a vidljiva je za sve autore.',
	'info_symbole_vert' => 'Simbol <b>zelene boje</b> označava <b>poruke razmjenjene sa drugim korisnicima</b> web sajta.',
	'info_telecharger_nouveau_logo' => 'otpremiti novi logotip:',
	'info_telecharger_ordinateur' => 'otpremiti sa Vašeg računala:',
	'info_tous_resultats_enregistres' => '[svi rezultati su obuhvaćeni]',
	'info_tout_afficher' => 'pokazati sve',
	'info_travaux_texte' => 'Ove web stranice još nisu postavljene. Posjetite nas nešto kasnije...',
	'info_travaux_titre' => 'web stranice u izgradnji',
	'info_trop_resultat' => 'previše rezultata za "@cherche_mot@"; molimo preciznije podatke.',
	'info_utilisation_messagerie_interne' => 'Vi koristite interne poruke na ovom sajtu.',
	'info_valider_lien' => 'odobriti ovaj link',
	'info_verifier_image' => ', molimo provjerite da li su Vaše slike uspješno prenešene.',
	'info_vignette_defaut' => 'standardna sličica',
	'info_vignette_personnalisee' => 'prilagođena sličica',
	'info_visite' => 'posjeta:',
	'info_vos_rendez_vous' => 'Vaše zakazane obveze',
	'infos_vos_pense_bete' => 'Vaše bilješke',

	// L
	'label_ajout_id_rapide' => 'Brzo dodavanje',
	'label_poids_fichier' => 'Veličina',
	'lien_afficher_icones_seuls' => 'prikazati samo sličice',
	'lien_afficher_texte_icones' => 'prikazati sličice i tekst',
	'lien_afficher_texte_seul' => 'prikazati samo tekst',
	'lien_liberer' => 'odobriti',
	'lien_liberer_tous' => 'odobriti ove članke',
	'lien_nouvea_pense_bete' => 'NOVA BILJEŠKA',
	'lien_nouveau_message' => 'NOVA PORUKA',
	'lien_nouvelle_annonce' => 'NOVA OBJAVA',
	'lien_petitions' => 'PETICIJA',
	'lien_popularite' => 'popularnost: @popularite@%',
	'lien_racine_site' => 'KORIJEN WEBA',
	'lien_reessayer' => 'pokušati ponovo',
	'lien_repondre_message' => 'odgovoriti na ovu poruku',
	'lien_supprimer' => 'obrisati',
	'lien_tout_afficher' => 'pokazati sve',
	'lien_visite_site' => 'posjetiti ove web stranice',
	'lien_visites' => '@visites@ posjeta',
	'lien_voir_auteur' => 'prikazati ovog autora',
	'ligne' => 'Linija',
	'login' => 'Spajanje',
	'login_acces_prive' => 'pristup redakcijskom sistemu',
	'login_autre_identifiant' => 'prijava pod drugim imenom',
	'login_cookie_accepte' => 'molimo, podesite Vaš browser da ih prihvati (barem za ove web stranice).',
	'login_cookie_oblige' => 'da biste se pouzdano identificirali, Vaš browser mora prihvatiti cookie.',
	'login_deconnexion_ok' => 'odjavljen.',
	'login_erreur_pass' => 'pogrešna lozinka.',
	'login_espace_prive' => 'redakcijski sistem',
	'login_identifiant_inconnu' => 'korisnik "@login@" je nepoznat.',
	'login_login' => 'prijava:',
	'login_login2' => 'prijava (korisničko ime za pristup web stranicama):',
	'login_login_pass_incorrect' => '(pogrešno korisničko ime ili lozinka).',
	'login_motpasseoublie' => 'zaboravljena lozinka?',
	'login_non_securise' => 'Oprez, ovaj formular nije siguran.
   Ako želite da Vaša lozinka bude nevidljiva u mreži,
   molimo aktivirajte JavaScript u Vašem browseru i',
	'login_nouvelle_tentative' => 'novi pokušaj',
	'login_par_ici' => 'Vi ste registrirani... idite ovamo...',
	'login_pass2' => 'lozinka:',
	'login_preferez_refuser' => '<b>Ako ne želite primiti cookie</b>, postoji drugi (manje siguran) način za spajanje:',
	'login_recharger' => 'osvježiti ovu stranicu',
	'login_rester_identifie' => 'upamti moj identitet nekoliko dana',
	'login_retour_public' => 'natrag u javni dio weba',
	'login_retour_site' => 'natrag u javni dio weba',
	'login_retoursitepublic' => 'natrag u javni dio weba',
	'login_securise' => 'Sigurnosna prijava',
	'login_sinscrire' => 'prijava',
	'login_test_navigateur' => 'ispitivanje browsera / ponovno spajanje',
	'login_verifiez_navigateur' => '(međutim, provjerite da li je Vaš browser možda upamtio Vašu lozinku...)',

	// M
	'masquer_colonne' => 'Sakriti ovaj stupac',
	'masquer_trad' => 'sakriti prijevode',
	'module_fichiers_langues' => 'jezične datoteke',

	// N
	'navigateur_pas_redirige' => 'Ako Vas Vaš browser ne odvede dalje, kliknite ovdje za nastavak.',
	'numero' => 'Broj',

	// O
	'occurence' => 'Instanca',
	'onglet_affacer_base' => 'obrisati bazu podataka',
	'onglet_auteur' => 'autor',
	'onglet_contenu_site' => 'sadržaj weba',
	'onglet_evolution_visite_mod' => 'razvitak posjeta',
	'onglet_fonctions_avances' => 'napredne fukcije',
	'onglet_informations_personnelles' => 'osobne informacije',
	'onglet_interactivite' => 'interaktivnost',
	'onglet_messagerie' => 'sistem za poruke',
	'onglet_repartition_rubrique' => 'raspodjela po rubrikama',
	'onglet_save_restaur_base' => 'snimiti / povratiti bazu podataka',
	'onglet_vider_cache' => 'isprazniti cache',

	// P
	'pass_choix_pass' => 'unesite Vašu novu lozinku:',
	'pass_erreur' => 'greška',
	'pass_erreur_acces_refuse' => '<b>greška:</b> Vi nemate više pristup ovim web stranicama.',
	'pass_erreur_code_inconnu' => '<b>greška:</b> ova oznaka ne odgovara niti jednom korisniku ovih web stranica.',
	'pass_erreur_non_enregistre' => '<b>greška:</b> adresa <tt>@email_oubli@</tt> nije registrirana na ovim web stranicama.',
	'pass_erreur_non_valide' => '<b>greška:</b> mail adresa <tt>@email_oubli@</tt> je neispravna!',
	'pass_erreur_probleme_technique' => '<b>greška:</b> ovaj mail nije mogao biti poslan zbog tehničkih poteškoća.',
	'pass_espace_prive_bla' => 'Redakcijski sistem je otvoren samo za registrirane korisnike.
Kad se registrirate, možete pregledati članke u obradi,
pisati nove članke i sudjelovati u svim forumima.',
	'pass_forum_bla' => 'Zatražili ste sudjelovanje u forumu koji je
rezerviran samo za registrirane korisnike.',
	'pass_indiquez_cidessous' => 'Unesite dolje mail adresu sa kojom se ste
ranije registrirali. Nakon toga ćete
dobiti mail sa uputama kako da ponovo
dobijete pristup.',
	'pass_mail_passcookie' => '(ovo je automatska poruka)

Da biste ponovo dobili pristup web stranicama
@nom_site_spip@ (@adresse_site@)

idite na slijedeću adresu:
    @sendcookie@

Tada možete unijeti novu lozinku i
ponovo dobiti pristup web stranicama.
',
	'pass_mot_oublie' => 'lozinka zaboravljena',
	'pass_nouveau_enregistre' => 'Vaša nova lozinka je upamćena.',
	'pass_nouveau_pass' => 'nova lozinka',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'lozinka zaboravljena',
	'pass_procedure_changer' => 'Kako bismo promjenili vašu lozinku, moramo prvo provjeriti vaš identitet. Stoga nam morate navesti mail adresu pridruženu vašem korisničkom računu.', # MODIF
	'pass_quitter_fenetre' => 'napustiti ovaj prozor',
	'pass_rappel_login' => 'podsjetnik: Vaše korisničko ime za prijavu (login) je "@login@".',
	'pass_recevoir_mail' => 'Primit ćete mail sa uputama za povrat pristupa web stranicama.',
	'pass_retour_public' => 'natrag u javno područje weba',
	'pass_rien_a_faire_ici' => 'ovdje se nema što raditi.',
	'pass_vousinscrire' => 'registrirati se na web stranicama',
	'precedent' => 'prethodno',
	'previsualisation' => 'provjeriti izgled',
	'previsualiser' => 'pokazati izgled',

	// R
	'retour' => 'Povratak',

	// S
	'spip_conforme_dtd' => 'SPIP nalazi da je ova stranica u skladu sa njenim DOCTYPE:',
	'squelette' => 'predložak',
	'squelette_inclus_ligne' => 'sadržani predložak, linija',
	'squelette_ligne' => 'predložak, linija',
	'stats_visites_et_popularite' => 'posjete: @visites@; popularnost: @popularite@',
	'suivant' => 'slijedeće',

	// T
	'taille_go' => '@taille@ Gb',
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Kad upoznate interface, kliknite na «',
	'texte_actualite_site_2' => 'potpuni interface',
	'texte_actualite_site_3' => '» da biste vidjeli više mogućnosti.',
	'texte_creation_automatique_vignette' => 'Ovaj web automatski pravi male sličice. Ako pomoću ovog formulara instalirate slike formata @gd_formats@, od njih će biti automatski napravljene i male sličice veličine maksimalno @taille_preview@ točaka.',
	'texte_documents_associes' => 'Slijedeći dokumenti pripadaju članku, ali nisu direkno uključeni u njega. Ovisno o izgledu javnog područja weba, oni se mogu tamo vidjeti kao pridruženi dokumenti.',
	'texte_erreur_mise_niveau_base' => 'Greška u bazi podataka prilikom unapređenja verzije.
Slika <b>@fichier@</b> nije mogla biti preuzeta (članak @id_article@).<p>
Brižljivo zabilježite ove oznake, i zatim ponovo pokušajte unaprediti verziju.
Nakon toga provjerite da li se slike pojavljuju u člancima.',
	'texte_erreur_visiteur' => 'Pokušali ste pristupiti privatnoj dijelu koristeći login koji to ne dozvoljava.',
	'texte_inc_auth_1' => 'Vi se ste predstavili korisničkim imenom
  <b>@auth_login@</b>, ali to korisničko ime ne postoji (više) u bazi podataka. 
  Pokušajte',
	'texte_inc_auth_2' => 'se ponovo spojiti',
	'texte_inc_auth_3' => ', nakon što ste zatvorili i ponovno pokrenuli Vaš browser.',
	'texte_inc_config' => 'Izmjene u slijedećim podešavanjima imaju veliki utjecaj na funkcioniranje ovih web stranica. Savjetujemo Vam da ništa ne mijenjate, osim ako dobro poznajete ustrojstvo programa
SPIP. <br /><br /><b>Uopćeno rečeno, izričito vam savjetujemo da izmjene prepustite glavnom administratoru web stranica.</b>',
	'texte_inc_meta_1' => 'Dogodila se greška prilikom pokušaja pisanja datoteke <code>@fichier@</code>. Ako ste Vi administrator, molim da',
	'texte_inc_meta_2' => 'dozvole pristupa',
	'texte_inc_meta_3' => 'za direktorij <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'obrada u toku',
	'texte_statut_poubelle' => 'obrisano',
	'texte_statut_propose_evaluation' => 'podnešeno na provjeru',
	'texte_statut_publie' => 'objavljeno',
	'texte_statut_refuse' => 'odbačeno',
	'titre_ajouter_mot_cle' => 'DODATI KLJUČNU RIJEČ:',
	'titre_cadre_raccourcis' => 'PREČACI:',
	'titre_changer_couleur_interface' => 'promjena boje interface-a',
	'titre_image_admin_article' => 'Vi možete upravljati ovim člankom',
	'titre_image_administrateur' => 'administrator',
	'titre_image_aide' => 'pomoć za ovu stavku',
	'titre_image_auteur_supprime' => 'autor obrisan',
	'titre_image_redacteur' => 'autor bez pristupa',
	'titre_image_redacteur_02' => 'autor',
	'titre_image_selecteur' => 'Prikazati popis',
	'titre_image_visiteur' => 'posjetitelj',
	'titre_joindre_document' => 'PRIDRUŽITI DOKUMENT',
	'titre_mots_cles' => 'KLJUČNE RIJEČI',
	'titre_probleme_technique' => 'Upozorenje: tehnički problem (SQL poslužitelj) onemogućava pristup ovom dijelu weba.  Hvala na razumijevanju.',
	'titre_publier_document' => 'OBJAVITI DOKUMENT U OVOJ RUBRICI',
	'titre_signatures_attente' => 'Potpisi koji čekaju na potvrdu',
	'titre_signatures_confirmees' => 'Potvrđeni potpisi',
	'titre_statistiques' => 'statistika web stranica',
	'titre_titre_document' => 'naslov dokumenta:',
	'todo' => 'u pripremi',
	'trad_reference' => '(referentni članak)',

	// Z
	'zbug_balise_b_aval' => ': tag B se mora nalaziti prije petlje',
	'zbug_balise_inexistante' => 'greška @from@: oznaka @balise@ ne postoji',
	'zbug_balise_sans_argument' => 'Nedostaje parametar u oznaci @balise@',
	'zbug_boucle' => 'petlja',
	'zbug_boucle_recursive_undef' => 'nedefinirana rekurzivna petlja: @nom@',
	'zbug_calcul' => 'proračun',
	'zbug_champ_hors_boucle' => 'polje @champ@ van petlje',
	'zbug_champ_hors_motif' => 'polje @champ@ van pripadajućeg konteksta (petlje) @motif@',
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'nepoznati kriterij @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} na tablici bez primarnog ključa',
	'zbug_distant_interdit' => 'vanjski podaci zabranjeni',
	'zbug_doublon_table_sans_cle_primaire' => 'Dvostruki zapisi u tablici koja ne posjeduje jednostavan primarni ključ',
	'zbug_doublon_table_sans_index' => 'Dvostruki zapisi u tablici bez indeksa',
	'zbug_erreur_boucle_double' => 'Petlja @id@: dvostruka definicija',
	'zbug_erreur_boucle_fermant' => 'Petlja @id@: nedostaje zatvarajuća oznaka',
	'zbug_erreur_boucle_syntaxe' => 'Nevaljana sintaksa petlje (BOUCLE) ',
	'zbug_erreur_compilation' => 'Greška pri kompilaciji',
	'zbug_erreur_execution_page' => 'Greška pri izvršenju',
	'zbug_erreur_filtre' => 'Nedefiniran filter @filtre@',
	'zbug_erreur_meme_parent' => '{meme_parent} je primjenljiv samo na (FORUMS) i (RUBRIQUES)',
	'zbug_erreur_squelette' => 'greška (greške) u predlošku (template)',
	'zbug_hors_compilation' => 'Nije kompilirano',
	'zbug_info_erreur_squelette' => 'greška na web stranicama',
	'zbug_inversion_ordre_inexistant' => 'Preokretanje nepostojećeg poretka',
	'zbug_pagination_sans_critere' => 'Oznaka #PAGINATION bez kriterija {pagination}, ili korištena u rekurzivnoj petlji',
	'zbug_parametres_inclus_incorrects' => 'Pogrešni parametri uključivanja: @param@',
	'zbug_profile' => 'Vrijeme računanja: @time@',
	'zbug_resultat' => 'rezultat',
	'zbug_serveur_indefini' => 'SQL poslužitelj nedefiniran',
	'zbug_statistiques' => 'Statistika SQL upita po redoslijedu trajanja',
	'zbug_table_inconnue' => 'nepoznata SQL tabela "@table@"',
	'zxml_connus_attributs' => 'poznata svojstva',
	'zxml_de' => 'od',
	'zxml_inconnu_attribut' => 'nepoznato svojstvo',
	'zxml_inconnu_balise' => 'nepoznata oznaka',
	'zxml_inconnu_entite' => 'nepoznati entitet',
	'zxml_inconnu_id' => 'nepoznat ID',
	'zxml_mais_de' => 'ali od',
	'zxml_non_conforme' => 'ne odgovara načelu',
	'zxml_non_fils' => 'nije dijete od',
	'zxml_nonvide_balise' => 'oznaka nije prazna',
	'zxml_obligatoire_attribut' => 'traženo svojstvo nedostaje u',
	'zxml_succession_fils_incorrecte' => 'pogrešno naslijeđivanje',
	'zxml_survoler' => 'da biste vidjeli ispravne, postavite kursor iznad ',
	'zxml_valeur_attribut' => 'vrijednost svojstva',
	'zxml_vide_balise' => 'prazna oznaka',
	'zxml_vu' => 'već viđeno'
);

?>
